@@ -143,32 +143,41 @@ class RegressionTransformerMolecules(AlgorithmConfiguration[Sequence, Sequence])
         An example for generating a peptide around a desired property value::
 
             config = RegressionTransformerMolecules(
-                search='sample', temperature=2, tolerance=5
+                algorithm_version='solubility', search='sample', temperature=2, tolerance=5
             )
             target = "<esol>-3.534|[Br][C][=C][C][MASK][MASK][=C][C][=C][C][=C][Ring1][MASK][MASK][Branch2_3][Ring1][Branch1_2]"
-            esol_generator = RegressionTransformer(
+            solubility_generator = RegressionTransformer(
                 configuration=config, target=target
             )
-            list(esol_generator.sample(5))
+            list(solubility_generator.sample(5))
 
         An example for predicting the solubility of a molecule::
 
-            config = RegressionTransformerMolecules(search='greedy')
+            config = RegressionTransformerMolecules(
+                algorithm_version='solubility', search='greedy'
+            )
             target = "<esol>[MASK][MASK][MASK][MASK][MASK]|[Cl][C][Branch1_2][Branch1_2][=C][Branch1_1][C][Cl][Cl][Cl]"
-            esol_generator = RegressionTransformer(
+            solubility_generator = RegressionTransformer(
                 configuration=config, target=target
             )
-            list(stability_generator.sample(1))
+            list(solubility_generator.sample(1))
     """
 
     algorithm_type: ClassVar[str] = "conditional_generation"
     domain: ClassVar[str] = "materials"
-    algorithm_version: str = "v0"
+    algorithm_version: str = field(
+        default="solubility",
+        metadata=dict(
+            description="The version of the algorithm to use.",
+            options=["solubility", "qed"],
+        ),
+    )
 
     search: str = field(
         default="sample",
         metadata=dict(
-            description="Search algorithm to use for the generation: sample or greedy"
+            description="Search algorithm to use for the generation: sample or greedy",
+            options=["sample", "greedy"],
         ),
     )
 
@@ -285,7 +294,13 @@ class RegressionTransformerProteins(AlgorithmConfiguration[Sequence, Sequence]):
 
     algorithm_type: ClassVar[str] = "conditional_generation"
     domain: ClassVar[str] = "materials"
-    algorithm_version: str = "v0"
+    algorithm_version: str = field(
+        default="stability",
+        metadata=dict(
+            description="The version of the algorithm to use.",
+            options=["stability"],
+        ),
+    )
 
     search: str = field(
         default="sample",
